@@ -1,7 +1,10 @@
 #line 1 "inc/Module/Install/Base.pm - /usr/local/share/perl/5.8.7/Module/Install/Base.pm"
 package Module::Install::Base;
 
-#line 28
+# Suspend handler for "redefined" warnings
+BEGIN { my $w = $SIG{__WARN__}; $SIG{__WARN__} = sub { $w } };
+
+#line 31
 
 sub new {
     my ($class, %args) = @_;
@@ -15,18 +18,18 @@ sub new {
     bless(\%args, $class);
 }
 
-#line 46
+#line 49
 
 sub AUTOLOAD {
     my $self = shift;
     goto &{$self->_top->autoload};
 }
 
-#line 57
+#line 60
 
 sub _top { $_[0]->{_top} }
 
-#line 68
+#line 71
 
 sub admin {
     my $self = shift;
@@ -49,6 +52,9 @@ sub DESTROY {}
 
 1;
 
+# Restore warning handler
+BEGIN { $SIG{__WARN__} = $SIG{__WARN__}->() };
+
 __END__
 
-#line 112
+#line 118
